package com.sn.sap.xgpre;

import java.io.File;
import java.io.FileOutputStream;
import java.util.Properties;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.sap.conn.jco.AbapException;
import com.sap.conn.jco.JCoDestination;
import com.sap.conn.jco.JCoDestinationManager;
import com.sap.conn.jco.JCoException;
import com.sap.conn.jco.JCoFunction;
import com.sap.conn.jco.JCoParameterList;
import com.sap.conn.jco.JCoTable;
import com.sap.conn.jco.ext.DestinationDataProvider;

public class ConnectPooled {// 连接池
	private static Log log = LogFactory.getLog(ConnectPooled.class);

	static String ABAP_AS_POOLED_XG_PRE = "ABAP_AS_POOLED_XG_PRE";
	static String ABAP_AS_POOLED_R3_DEV = "ABAP_AS_POOLED_R3_DEV";
	static {
		config("192.168.118.xx");// dev
		config("10.242.6.xxx");// pre
	}

	private static void config(String ip) {
		Properties connectProperties = new Properties();
		connectProperties.setProperty(DestinationDataProvider.JCO_ASHOST, ip);
		connectProperties.setProperty(DestinationDataProvider.JCO_SYSNR, "00");
		connectProperties
				.setProperty(DestinationDataProvider.JCO_CLIENT, "200");
		connectProperties.setProperty(DestinationDataProvider.JCO_USER,
				"1504xxxx");
		// 注：密码是区分大小写的，要注意大小写
		connectProperties.setProperty(DestinationDataProvider.JCO_PASSWD,
				"axxxxxx");
		connectProperties.setProperty(DestinationDataProvider.JCO_LANG, "en");

		// *********连接池方式与直接不同的是设置了下面两个连接属性
		// JCO_PEAK_LIMIT - 同时可创建的最大活动连接数，0表示无限制，默认为JCO_POOL_CAPACITY的值
		// 如果小于JCO_POOL_CAPACITY的值，则自动设置为该值，在没有设置JCO_POOL_CAPACITY的情况下为0
		connectProperties.setProperty(DestinationDataProvider.JCO_PEAK_LIMIT,
				"10");
		// JCO_POOL_CAPACITY - 空闲连接数，如果为0，则没有连接池效果，默认为1
		connectProperties.setProperty(
				DestinationDataProvider.JCO_POOL_CAPACITY, "3");

		createDataFile(ABAP_AS_POOLED_XG_PRE, "jcoDestination",
				connectProperties);
	}

	static void createDataFile(String name, String suffix, Properties properties) {
		File cfg = new File(name + "." + suffix);
		if (!cfg.exists()) {
			try {
				FileOutputStream fos = new FileOutputStream(cfg, false);
				properties.store(fos, "for tests only !");
				fos.close();
			} catch (Exception e) {
				log.error("", e);
			}
		}
	}

	/**
	 * 
	 * @param REQUESTNO
	 * @return
	 * @throws JCoException
	 */
	public static JCoTable getTransRequestFiles(String REQUESTNO)
			throws JCoException {
		JCoDestination destination = JCoDestinationManager
				.getDestination(ABAP_AS_POOLED_R3_DEV);
		JCoFunction function = destination.getRepository().getFunction(
				"ZXG_PRE_FUC");// 从对象仓库中获取 RFM 函数
		if (function == null)
			throw new RuntimeException("ZXG_PRE_FUC not found in SAP.");

		JCoParameterList jpl = function.getImportParameterList();
		jpl.setValue("REQUESTNO", REQUESTNO);
		try {
			function.execute(destination);
		} catch (AbapException e) {
			log.error("", e);
			return null;
		}

		jpl = function.getExportParameterList();
		JCoTable jt = jpl.getTable("FILES");

		return jt;
	}

	/**
	 * 
	 * @param jt
	 * @param req
	 * @throws JCoException
	 */
	public static void sendTransReqFiles2xgpre(JCoTable jt, String req)
			throws JCoException {
		JCoDestination destination = JCoDestinationManager
				.getDestination(ABAP_AS_POOLED_XG_PRE);
		JCoFunction function = destination.getRepository().getFunction(
				"ZXG_PRE_FUC");// 从对象仓库中获取 RFM 函数
		if (function == null)
			throw new RuntimeException("ZXG_PRE_FUC not found in SAP.");

		function.getImportParameterList().setValue("FILES", jt);
		function.getImportParameterList().setValue("REQUESTNOS", req);

		try {
			function.execute(destination);
		} catch (AbapException e) {
			log.error("", e);
		}
	}
}
