package com.sn.sap.xgpre;

import java.io.IOException;

import javax.servlet.http.HttpServletResponse;

import com.alibaba.fastjson.JSONObject;

public final class JsonPrintUtil {

	private JsonPrintUtil() {
	}

	/**
	 * 输出 map 的 json 格式
	 *
	 * @param response
	 *            {@link javax.servlet.http.HttpServletResponse HttpServletResponse}
	 * @param jsonObject
	 *            待输出的 json
	 */
	public static void printJson(HttpServletResponse response, JSONObject jsonObject) {
		internalPrint(response, jsonObject);
	}

	/**
	 * 输出 json 格式的消息
	 *
	 * @param response
	 *            {@link javax.servlet.http.HttpServletResponse HttpServletResponse}
	 * @param isSuccess
	 *            成功 true，失败 false
	 * @param msg
	 *            响应消息
	 */
	public static void printJson(HttpServletResponse response, boolean isSuccess, String msg) {
		JSONObject obj = new JSONObject();
		obj.put("isSuccess", isSuccess);
		obj.put("msg", msg);

		internalPrint(response, obj);
	}

	public static void printJson(HttpServletResponse response, boolean isSuccess, String msg, Object dataContent) {
		JSONObject obj = new JSONObject();
		obj.put("isSuccess", isSuccess);
		obj.put("msg", msg);
		obj.put("data", dataContent);

		internalPrint(response, obj);
	}

	/**
	 * 输出 json 格式的消息
	 *
	 * @param response
	 *            {@link javax.servlet.http.HttpServletResponse HttpServletResponse}
	 * @param isSuccess
	 *            成功 true，失败 false
	 * @param msg
	 *            响应消息
	 * @param pageNo
	 *            当前页码
	 * @param pageSize
	 *            每页行数
	 * @param totalCount
	 *            总计行数
	 * @param list
	 *            列表数据
	 */
	public static void printJson(HttpServletResponse response, boolean isSuccess, String msg, Integer pageNo,
			Integer pageSize, Integer totalCount, String list) {
		JSONObject obj = new JSONObject();
		obj.put("isSuccess", isSuccess);
		obj.put("msg", msg);
		obj.put("pageNo", pageNo);
		obj.put("pageSize", pageSize);
		obj.put("totalCount", totalCount);
		obj.put("list", list);

		internalPrint(response, obj);
	}

	/**
	 * 输出 json 格式的消息
	 *
	 * @param response
	 *            {@link javax.servlet.http.HttpServletResponse HttpServletResponse}
	 * @param isSuccess
	 *            成功 true，失败 false
	 * @param msg
	 *            响应消息
	 * @param pageNo
	 *            当前页码
	 * @param pageSize
	 *            每页行数
	 * @param totalCount
	 *            总计行数
	 * @param list
	 *            列表数据
	 */
	public static void printJson(HttpServletResponse response, boolean isSuccess, String msg, Integer pageNo,
			Integer pageSize, Integer totalCount, String list, String dateList) {
		JSONObject obj = new JSONObject();
		obj.put("isSuccess", isSuccess);
		obj.put("msg", msg);
		obj.put("pageNo", pageNo);
		obj.put("pageSize", pageSize);
		obj.put("totalCount", totalCount);
		obj.put("list", list);
		obj.put("dateList", dateList);

		internalPrint(response, obj);
	}

	private static void internalPrint(HttpServletResponse response, JSONObject json) {
		response.setCharacterEncoding("UTF-8");
		// 兼容 ie
		response.setContentType("text/html; charset=UTF-8");

		try {
			response.getWriter().print(json.toString());
			response.getWriter().flush();
			response.getWriter().close();
		} catch (IOException ex) {
			// 不应当发生
			throw new IllegalStateException(ex);
		}
	}

	public static void print(HttpServletResponse response, String msg) {
		try {
			response.setCharacterEncoding("UTF-8");
			// 兼容 ie
			response.setContentType("text/html; charset=UTF-8");
			response.getWriter().write(msg);
			response.getWriter().flush();
			response.getWriter().close();
		} catch (IOException ex) {
			// 不应当发生
			throw new IllegalStateException(ex);
		}
	}
}
